@@ -57,6 +57,8 @@ my %hierarchy = (
     'BoxElement' => 'MathElement',
     'BubbleChartDataPoint' => 'ScatterChartDataPoint',
     'BubbleSeries' => 'XYSeries',
+    'CaptionTrack' => 'ResourceBase',
+    'CaptionTracks' => 'ResourceBase',
     'Chart' => 'ShapeBase',
     'ClosePathSegment' => 'PathSegment',
     'ColorChangeEffect' => 'ImageTransformEffect',
@@ -224,6 +226,8 @@ my %determiners = (
     'BubbleChartDataPoint' => { 'Type' => 'Bubble', },
     'BubbleSeries' => { 'DataPointType' => 'Bubble', },
     'Camera' => {  },
+    'CaptionTrack' => {  },
+    'CaptionTracks' => {  },
     'Chart' => { 'Type' => 'Chart', },
     'ChartCategory' => {  },
     'ChartLinesFormat' => {  },
